@@ -10,8 +10,7 @@
 #include "globals.h"
 #include "settings.h"
 // KDEGames
-#include <kdegames_version.h>
-#include <KgSound>
+#include <KGameSound>
 // KF
 #include <KMessageBox>
 #include <KLocalizedContext>
@@ -24,7 +23,7 @@
 GameView::GameView(QWidget *parent) :
     QQuickWidget(parent),
     grid(new AbstractGrid),
-    m_provider(new KgThemeProvider)
+    m_provider(new KGameThemeProvider)
 {
     QQmlEngine *engine = this->engine();
 
@@ -33,15 +32,11 @@ GameView::GameView(QWidget *parent) :
 
     setResizeMode(SizeRootObjectToView);
 
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
     m_provider->discoverThemes(QStringLiteral("themes"));
-#else
-    m_provider->discoverThemes("appdata", QStringLiteral("themes"));
-#endif
     m_provider->setDeclarativeEngine(QStringLiteral("themeProvider"), engine);
-    m_soundTurn = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/turn.wav")), this);
-    m_soundClick = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/click.wav")), this);
-    m_soundConnect = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/connect.wav")), this);
+    m_soundTurn = new KGameSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/turn.wav")), this);
+    m_soundClick = new KGameSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/click.wav")), this);
+    m_soundConnect = new KGameSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/connect.wav")), this);
     QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("qml/main.qml"));
 
     setSource(QUrl::fromLocalFile(path));
